# Collaborating and Managing Data in Fact Sheets
### On this page
  * [Introduction](https://help.sap.com/docs/leanix/ea/collaborating-and-managing-data-in-fact-sheets#introduction)
  * [Fact Sheet Subscriptions](https://help.sap.com/docs/leanix/ea/collaborating-and-managing-data-in-fact-sheets#fact-sheet-subscriptions)
  * [Commenting on Fact Sheets](https://help.sap.com/docs/leanix/ea/collaborating-and-managing-data-in-fact-sheets#commenting-on-fact-sheets)
  * [Delegating Responsibilities Using To-Dos](https://help.sap.com/docs/leanix/ea/collaborating-and-managing-data-in-fact-sheets#delegating-responsibilities-using-to-dos)
  * [Storing Resources on Fact Sheets](https://help.sap.com/docs/leanix/ea/collaborating-and-managing-data-in-fact-sheets#storing-resources-on-fact-sheets)
  * [Managing Transformations Associated with Fact Sheets](https://help.sap.com/docs/leanix/ea/collaborating-and-managing-data-in-fact-sheets#managing-transformations-associated-with-fact-sheets)
  * [Answering Survey Questions](https://help.sap.com/docs/leanix/ea/collaborating-and-managing-data-in-fact-sheets#answering-survey-questions)
  * [Reviewing the Fact Sheet Update Log](https://help.sap.com/docs/leanix/ea/collaborating-and-managing-data-in-fact-sheets#reviewing-the-fact-sheet-update-log)
  * [Right Side Pane of Fact Sheet](https://help.sap.com/docs/leanix/ea/collaborating-and-managing-data-in-fact-sheets#right-side-pane-of-fact-sheet)


Explore how to collaborate and manage data in SAP LeanIX fact sheets. Learn how to add and handle data across various tabs of the fact sheet, including Subscriptions, Comments, To-dos, Resources, Transformations, and Surveys.
